@@ -74,7 +74,8 @@ class Move(metaclass=PoolMeta):
 
         # Compute average cost price
         unit_price = self.unit_price
-        self.unit_price = cost_price
+        self.unit_price = Uom.compute_price(
+            self.product.default_uom, cost_price, self.uom)
         average_cost_price = self._compute_product_cost_price('out')
         self.unit_price = unit_price
 
